/*
 * Sonar Delphi Plugin
 * Copyright (C) 2011 Sabre Airline Solutions
 * Author(s):
 * Przemyslaw Kociolek (przemyslaw.kociolek@sabre.com)
 * Michal Wojcik (michal.wojcik@sabre.com)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02
 */
package org.sonar.plugins.delphi.antlr.directives.impl;

import org.sonar.plugins.delphi.antlr.directives.CompilerDirectiveType;

/**
 * Class for unused compiler directives, such as: {$I+-} {$WARN} and so on. They do not affect parsing and processing a certain file. This
 * class will prevent from writing CompilerDirectiveFactoryUnsupportedDirectiveException to log file.
 */
public class UnusedDirective extends CommonCompilerDirective {

  /**
   * ctor
   * 
   * @param firstCharPos
   *          first character position
   * @param lastCharPos
   *          last character position
   */
  public UnusedDirective(int firstCharPos, int lastCharPos) {
    super("unused", "", firstCharPos, lastCharPos);
  }

  /**
   * returns UNUSED
   */

  @Override
  public CompilerDirectiveType getType() {
    return CompilerDirectiveType.UNUSED;
  }

}
